==> mdk-0.4a.tar.gz: mdk-0.4/mixgtk/mixgtk_mixvm.h <==
/* -*-c-*- ---------------- mixgtk_mixvm.h :
 * Functions dealing with the mixvm widgets
 * ------------------------------------------------------------------
 *  Last change: Time-stamp: <01/03/09 22:12:04 jose>
 * ------------------------------------------------------------------
 * Copyright (C) 2001 Free Software Foundation, Inc.
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *  
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *  
 */


#ifndef MIXGTK_MIXVM_H
#define MIXGTK_MIXVM_H

#include <mixlib/mix_vm.h>
#include "mixgtk.h"
#include "mixgtk_widgets.h"

/* initialise the mixvm widgets */
extern gboolean
mixgtk_mixvm_init (mix_vm_t *vm, mixgtk_dialog_id_t top);

/* update register widgets */
extern void
mixgtk_mixvm_update_registers (void);

/* update the overflow toggle */
extern void
mixgtk_mixvm_update_over_toggle (void);

/* update the comparison flag */
extern void
mixgtk_mixvm_update_cmp (void);

/* update the memory cells */
extern void
mixgtk_mixvm_update_cells (void);

extern void
mixgtk_mixvm_update_cells_to_address (gint address);

/* update the loc pointer */
extern void
mixgtk_mixvm_update_loc (void);

/* update times */
extern void
mixgtk_mixvm_update_times (void);

/* update all mixvm widgets */
extern void
mixgtk_mixvm_update_vm_widgets (void);

/* callbacks */
extern void
on_cmp_e_toggled (GtkWidget *widget, gpointer data);

extern void
on_cmp_g_toggled (GtkWidget *widget, gpointer data);

extern void
on_cmp_l_toggled (GtkWidget *widget, gpointer data);

extern void
on_overflow_toggled (GtkWidget *widget, gpointer data);

extern void
on_loc_arrow_clicked (GtkWidget *widget, gpointer data);

				 

#endif /* MIXGTK_MIXVM_H */

==> mdk-1.2.tar.gz: mdk-1.2/mixgtk/mixgtk_mixvm.h <==
/* -*-c-*- ---------------- mixgtk_mixvm.h :
 * Functions dealing with the mixvm widgets
 * ------------------------------------------------------------------
 * $Id: mixgtk_mixvm.h,v 1.5 2004/07/04 22:34:15 jao Exp $
 * ------------------------------------------------------------------
 * Copyright (C) 2001, 2004 Free Software Foundation, Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#ifndef MIXGTK_MIXVM_H
#define MIXGTK_MIXVM_H

#include <mixlib/mix_vm.h>
#include "mixgtk.h"
#include "mixgtk_widgets.h"

/* initialise the mixvm widgets */
extern gboolean
mixgtk_mixvm_init (mix_vm_t *vm);

extern void
mixgtk_mixvm_update_fonts (void);

/* update register widgets */
extern void
mixgtk_mixvm_update_registers (void);

/* update the overflow toggle */
extern void
mixgtk_mixvm_update_over_toggle (void);

/* update the comparison flag */
extern void
mixgtk_mixvm_update_cmp (void);

/* update the memory cells */
extern void
mixgtk_mixvm_update_cells (void);

extern void
mixgtk_mixvm_update_cells_to_address (gint address);

/* update the loc pointer */
extern void
mixgtk_mixvm_update_loc (void);

/* update times */
extern void
mixgtk_mixvm_update_times (void);

/* update all mixvm widgets */
extern void
mixgtk_mixvm_update_vm_widgets (void);


#endif /* MIXGTK_MIXVM_H */
